@@ -7,6 +7,7 @@
 #' \describe{
 #'   \item{example_maxtime}{The number of seconds allowed for a given example to run. It is used to control whether the longer examples should be run or not based on the comparison between this option and the approximate running time of the example on our computers.}
 #'   \item{Ncpu}{An \var{integer} corresponding to the number of cores to be used (for future version)}
+#'   \item{dont_ask}{A \var{logical} indicating if the user prompt during interactive session during plotting must be inactivated (for development purposes only)}
 #' }
 #'
 #' @return The options invisibly in an object called \code{.IsoriX.data$options}
@@ -18,6 +19,7 @@
 #'
 #' \dontrun{
 #' IsoriX.options(example_maxtime = 30)
+#' IsoriX.options()
 #' }
 
 IsoriX.options <- function(...) { ## as in spaMM
@@ -45,17 +47,26 @@ IsoriX.options <- function(...) { ## as in spaMM
 #' @export
 
 IsoriX.getOption <- function(x) {
-  if (x == "Ncpu" && (IsoriX.options(x)[[1]] > parallel::detectCores())) {
-    warning(paste(IsoriX.options(x)[[1]],
+  if (x == "Ncpu" && (IsoriX.options(x)[["Ncpu"]] > parallel::detectCores())) {
+    warning(paste(IsoriX.options(x)[["Ncpu"]],
                   "CPUs were requested, but the maximum number of CPU on this machine is",
                   parallel::detectCores(),
                   "so the Ncpu option of this package has been corrected"))
     IsoriX.options(Ncpu = parallel::detectCores())
   }
-  IsoriX.options(x)[[1]]
+  if (x == "Ncpu") {
+    return(IsoriX.options(x)[["Ncpu"]])
+  }
+  if (x == "example_maxtime") {
+    return(IsoriX.options(x)[["example_maxtime"]])
+  }
+  if (x == "dont_ask") {
+    return(IsoriX.options(x)[["dont_ask"]])
+  }
+  stop("option not found")
 }
 
 ## Setting default package options
-.IsoriX.data <- new.env(parent = emptyenv())
-.IsoriX.data$options <- list(example_maxtime = 5, Ncpu = 2L)  ## put example_maxtime = 500 to check all examples
+.IsoriX.data$options <- list(example_maxtime = 5, Ncpu = 2L, dont_ask = FALSE)  ## put example_maxtime = 500 to check all examples
+                                                                                ## otherwise put 5
 
